Sync with portage [Fri Sep 9 14:19:47 MSK 2016].

mhiretskiy 527
root 8 years ago
parent 8114f6c99d
commit 0ff20c0563

@ -2,3 +2,4 @@ DIST sudo-1.8.15.tar.gz 2660128 SHA256 4316381708324da8b6cb151f655c1a11855207c7c
DIST sudo-1.8.16.tar.gz 2707358 SHA256 2d83826fc5125bf073acc203dbda1cf2abeee017090ccc9dddb0431a53d5064d SHA512 7cf5399eb65c4b39071213c27c34d35ed2ea9c4578f19f6e8d3777179914fa30a2848c042e9f85e90e3b5d056322b9eb6c79e2d3b9b210a795e9921a1b00200b WHIRLPOOL 747bff26e93475441aab6bb6ff8e51114f8155277d570cbdb28909b7e63a49fcdcf5d65f186a2ec067f1100cac3c0a2e6f3a7611f78d83794f41d6884a8c6fc9
DIST sudo-1.8.17.tar.gz 2786216 SHA256 62b12c4fa9a3ad4f20f6e7576bc6405b2ec8d76222ea44a1c94830c68cccec8c SHA512 475d8357f2b6b0542f886db544465ff386311893babccb7b6603dac0deb82a9a6c50e82a3d7bee2713de79556e0ec326240fd8766deadbe05569a92a790e62d5 WHIRLPOOL dc81953d266a9fad674bd25688a59013f89aeecd7c61e75f9d246f8671b703542820bc8318bb584c8a1b9ec78af16498f3e0f253e0a83c90e6055fde6f9bc0d1
DIST sudo-1.8.17p1.tar.gz 2786618 SHA256 c690d707fb561b3ecdf6a6de5563bc0b769388eff201c851edbace408bb155cc SHA512 e9facd2d5578d4effb516931322b5f4f9578baa779cba281d36a3d0995b1fd9d085d6b141544b3dc698569fa294163bbad9f779166a05a0f18f4ad81a630b954 WHIRLPOOL 7b89fa9f05bbe72929073d83433f21b5a783047118ae7d434cb08cb536d5e47a641c59f5b4c7310c73d7dc994331974e4f209700e83139c2847f68e7dba014b2
DIST sudo-1.8.18rc1.tar.gz 2820338 SHA256 f2ec86ac5327fc401fc1dcfeaeaa596b48f639a5e14a1a5b5b992909896f49cf SHA512 8cdc21bc08767f86674f42525a6e3c03dbbb9d6a4652914d53989149cc924644b38b7191873d66e7c234e87eb527444f6ff78b6e8f979f900a147c94d313bc05 WHIRLPOOL 6e2b43dfd61c6323ce92c99f5ec3490aac1d96ffc122e9399ffa7ee74c0bf51fe513ce5a0603b1f41686f7a9b2a3c961b668fac5b14d4dbb62a7c4ff4b1c10ef

@ -0,0 +1,202 @@
# Copyright 1999-2016 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Id$
EAPI=6
inherit eutils pam multilib libtool
MY_P=${P/_/}
MY_P=${MY_P/beta/b}
uri_prefix=
case ${P} in
*_beta*|*_rc*) uri_prefix=beta/ ;;
esac
DESCRIPTION="Allows users or groups to run commands as other users"
HOMEPAGE="http://www.sudo.ws/"
SRC_URI="http://www.sudo.ws/sudo/dist/${uri_prefix}${MY_P}.tar.gz
ftp://ftp.sudo.ws/pub/sudo/${uri_prefix}${MY_P}.tar.gz"
# Basic license is ISC-style as-is, some files are released under
# 3-clause BSD license
LICENSE="ISC BSD"
SLOT="0"
if [[ ${PV} != *_beta* ]] && [[ ${PV} != *_rc* ]] ; then
KEYWORDS="~alpha ~amd64 ~arm ~arm64 ~hppa ~ia64 ~m68k ~mips ~ppc ~ppc64 ~s390 ~sh ~sparc ~x86 ~amd64-fbsd ~sparc-fbsd ~x86-fbsd ~x64-freebsd ~sparc-solaris"
fi
IUSE="ldap nls pam offensive selinux skey +sendmail"
DEPEND="pam? ( virtual/pam )
skey? ( >=sys-auth/skey-1.1.5-r1 )
ldap? (
>=net-nds/openldap-2.1.30-r1
dev-libs/cyrus-sasl
)
sys-libs/zlib"
RDEPEND="${DEPEND}
selinux? ( sec-policy/selinux-sudo )
ldap? ( dev-lang/perl )
pam? ( sys-auth/pambase )
>=app-misc/editor-wrapper-3
virtual/editor
sendmail? ( virtual/mta )"
DEPEND="${DEPEND}
sys-devel/bison"
S=${WORKDIR}/${MY_P}
REQUIRED_USE="pam? ( !skey ) skey? ( !pam )"
MAKEOPTS+=" SAMPLES="
src_prepare() {
default
elibtoolize
}
set_rootpath() {
# FIXME: secure_path is a compile time setting. using ROOTPATH
# is not perfect, env-update may invalidate this, but until it
# is available as a sudoers setting this will have to do.
einfo "Setting secure_path ..."
# first extract the default ROOTPATH from build env
ROOTPATH=$(unset ROOTPATH; . "${EPREFIX}"/etc/profile.env; echo "${ROOTPATH}")
if [[ -z ${ROOTPATH} ]] ; then
ewarn " Failed to find ROOTPATH, please report this"
fi
# then remove duplicate path entries
cleanpath() {
local newpath thisp IFS=:
for thisp in $1 ; do
if [[ :${newpath}: != *:${thisp}:* ]] ; then
newpath+=:$thisp
else
einfo " Duplicate entry ${thisp} removed..."
fi
done
ROOTPATH=${newpath#:}
}
cleanpath /bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:/opt/bin${ROOTPATH:+:${ROOTPATH}}
# finally, strip gcc paths #136027
rmpath() {
local e newpath thisp IFS=:
for thisp in ${ROOTPATH} ; do
for e ; do [[ $thisp == $e ]] && continue 2 ; done
newpath+=:$thisp
done
ROOTPATH=${newpath#:}
}
rmpath '*/gcc-bin/*' '*/gnat-gcc-bin/*' '*/gnat-gcc/*'
einfo "... done"
}
src_configure() {
local ROOTPATH
set_rootpath
# audit: somebody got to explain me how I can test this before I
# enable it.. - Diego
# plugindir: autoconf code is crappy and does not delay evaluation
# until `make` time, so we have to use a full path here rather than
# basing off other values.
econf \
--enable-zlib=system \
--with-secure-path="${ROOTPATH}" \
--with-editor="${EPREFIX}"/usr/libexec/editor \
--with-env-editor \
$(use_with offensive insults) \
$(use_with offensive all-insults) \
$(use_with ldap ldap_conf_file /etc/ldap.conf.sudo) \
$(use_with ldap) \
$(use_enable nls) \
$(use_with pam) \
$(use_with skey) \
$(use_with selinux) \
$(use_with sendmail) \
--without-opie \
--without-linux-audit \
--with-rundir="${EPREFIX}"/var/run/sudo \
--with-vardir="${EPREFIX}"/var/db/sudo \
--with-plugindir="${EPREFIX}"/usr/$(get_libdir)/sudo \
--docdir="${EPREFIX}"/usr/share/doc/${PF}
}
src_install() {
default
if use ldap ; then
dodoc README.LDAP
dosbin plugins/sudoers/sudoers2ldif
cat <<-EOF > "${T}"/ldap.conf.sudo
# See ldap.conf(5) and README.LDAP for details
# This file should only be readable by root
# supported directives: host, port, ssl, ldap_version
# uri, binddn, bindpw, sudoers_base, sudoers_debug
# tls_{checkpeer,cacertfile,cacertdir,randfile,ciphers,cert,key}
EOF
insinto /etc
doins "${T}"/ldap.conf.sudo
fperms 0440 /etc/ldap.conf.sudo
insinto /etc/openldap/schema
newins doc/schema.OpenLDAP sudo.schema
fi
pamd_mimic system-auth sudo auth account session
keepdir /var/db/sudo
fperms 0700 /var/db/sudo
# Don't install into /var/run as that is a tmpfs most of the time
# (bug #504854)
rm -rf "${D}"/var/run
}
pkg_postinst() {
if use ldap ; then
ewarn
ewarn "sudo uses the /etc/ldap.conf.sudo file for ldap configuration."
ewarn
if grep -qs '^[[:space:]]*sudoers:' "${ROOT}"/etc/nsswitch.conf ; then
ewarn "In 1.7 series, LDAP is no more consulted, unless explicitly"
ewarn "configured in /etc/nsswitch.conf."
ewarn
ewarn "To make use of LDAP, add this line to your /etc/nsswitch.conf:"
ewarn " sudoers: ldap files"
ewarn
fi
fi
if use prefix ; then
ewarn
ewarn "To use sudo, you need to change file ownership and permissions"
ewarn "with root privileges, as follows:"
ewarn
ewarn " # chown root:root ${EPREFIX}/usr/bin/sudo"
ewarn " # chown root:root ${EPREFIX}/usr/lib/sudo/sudoers.so"
ewarn " # chown root:root ${EPREFIX}/etc/sudoers"
ewarn " # chown root:root ${EPREFIX}/etc/sudoers.d"
ewarn " # chown root:root ${EPREFIX}/var/db/sudo"
ewarn " # chmod 4111 ${EPREFIX}/usr/bin/sudo"
ewarn
fi
elog "To use the -A (askpass) option, you need to install a compatible"
elog "password program from the following list. Starred packages will"
elog "automatically register for the use with sudo (but will not force"
elog "the -A option):"
elog ""
elog " [*] net-misc/ssh-askpass-fullscreen"
elog " net-misc/x11-ssh-askpass"
elog ""
elog "You can override the choice by setting the SUDO_ASKPASS environmnent"
elog "variable to the program you want to use."
}

@ -1,24 +0,0 @@
Make configure script work for Python 3.
In Python 3, map returns an iterable, not a list, so for a subsequent map to
work we have to convert that to a list explicitely. This should work for
Python 2 just as well, so the patch can be applied unconditionally.
2013-09-21 Martin von Gagern
References:
https://bugs.gentoo.org/485490
Index: Botan-1.10.5/configure.py
===================================================================
--- Botan-1.10.5.orig/configure.py
+++ Botan-1.10.5/configure.py
@@ -1780,7 +1780,7 @@ def main(argv = None):
gcc_version = stdout.strip()
logging.info('Detected gcc version %s' % (gcc_version))
- return map(int, gcc_version.split('.')[0:2])
+ return [int(c) for c in gcc_version.split('.')[0:2]]
except OSError:
logging.warning('Could not execute %s for version check' % (gcc_bin))
return None

@ -1,35 +0,0 @@
From 5bb0b47e608e083dda5e39132174b840f3b091cf Mon Sep 17 00:00:00 2001
From: Alon Bar-Lev <alon.barlev@gmail.com>
Date: Tue, 15 Sep 2015 00:18:19 +0300
Subject: [PATCH] build: support multiple python versions
Signed-off-by: Alon Bar-Lev <alon.barlev@gmail.com>
---
src/scripts/install.py | 11 ++++++-----
1 file changed, 6 insertions(+), 5 deletions(-)
diff --git a/src/scripts/install.py b/src/scripts/install.py
index 2c69213..d1d62b6 100755
--- a/src/scripts/install.py
+++ b/src/scripts/install.py
@@ -181,11 +181,12 @@ def main(args = None):
os.path.join(pkgconfig_dir, os.path.basename(cfg['botan_pkgconfig'])))
if 'ffi' in cfg['mod_list'].split('\n'):
- py_lib_path = os.path.join(lib_dir, 'python%s' % (cfg['python_version']), 'site-packages')
- logging.debug('Installing python module to %s' % (py_lib_path))
- makedirs(py_lib_path)
- for py in ['botan.py']:
- copy_file(os.path.join(cfg['python_dir'], py), os.path.join(py_lib_path, py))
+ for ver in cfg['python_version'].split(','):
+ py_lib_path = os.path.join(lib_dir, 'python%s' % (ver), 'site-packages')
+ logging.debug('Installing python module to %s' % (py_lib_path))
+ makedirs(py_lib_path)
+ for py in ['botan.py']:
+ copy_file(os.path.join(cfg['python_dir'], py), os.path.join(py_lib_path, py))
shutil.rmtree(target_doc_dir, True)
shutil.copytree(cfg['doc_output_dir'], target_doc_dir)
--
2.4.6

@ -1,36 +0,0 @@
--- makefile
+++ makefile
@@ -241,8 +241,7 @@
OBJS = $(BNOBJS) $(CERTOBJS) $(CRYPTOBJS) $(CTXOBJS) $(DEVOBJS) \
$(ENVOBJS) $(HASHOBJS) $(IOOBJS) $(KEYSETOBJS) $(KRNLOBJS) \
- $(LIBOBJS) $(MECHOBJS) $(MISCOBJS) $(SESSOBJS) $(ZLIBOBJS) \
- $(OSOBJS)
+ $(LIBOBJS) $(MECHOBJS) $(MISCOBJS) $(SESSOBJS) $(OSOBJS)
# Object files for the self-test code
@@ -1299,7 +1298,7 @@
$(SLIBNAME): $(OBJS) $(EXTRAOBJS) $(TESTOBJS)
@./tools/buildsharedlib.sh $(OSNAME) $(SLIBNAME) $(LD) $(OBJS) \
- $(EXTRAOBJS)
+ $(EXTRAOBJS) -lz
$(DYLIBNAME): $(OBJS) $(EXTRAOBJS) $(TESTOBJS)
@$(LD) -dynamiclib -compatibility_version $(MAJ).$(MIN) \
--- envelope/envelope.h
+++ envelope/envelope.h
@@ -17,11 +17,7 @@
#endif /* Compiler-specific includes */
#endif /* _STREAM_DEFINED */
#ifdef USE_COMPRESSION
- #if defined( INC_ALL )
- #include "zlib.h"
- #else
- #include "zlib/zlib.h"
- #endif /* Compiler-specific includes */
+ #include <zlib.h>
#endif /* USE_COMPRESSION */
/****************************************************************************

@ -1,49 +0,0 @@
From a36ee7501f68ad7ebcfe31f9659430b9d2c3ddd1 Mon Sep 17 00:00:00 2001
From: NIIBE Yutaka <gniibe@fsij.org>
Date: Thu, 11 Jun 2015 16:19:49 +0900
Subject: [PATCH 1/1] mpi: Support FreeBSD 10 or later.
* mpi/config.links: Include FreeBSD 10 to 29.
--
Thanks to Yuta SATOH.
GnuPG-bug-id: 1936, 1974
---
mpi/config.links | 12 +++++++-----
1 file changed, 7 insertions(+), 5 deletions(-)
diff --git a/mpi/config.links b/mpi/config.links
index 2fb5e8a..3ead4f0 100644
--- a/mpi/config.links
+++ b/mpi/config.links
@@ -50,11 +50,12 @@ case "${host}" in
path=""
mpi_cpu_arch="x86"
;;
- i[3467]86*-*-openbsd* | \
- i[3467]86*-*-freebsd*-elf | \
- i[3467]86*-*-freebsd[3-9]* | \
- i[3467]86*-*-freebsdelf* | \
- i[3467]86*-*-netbsd* | \
+ i[3467]86*-*-openbsd* | \
+ i[3467]86*-*-freebsd*-elf | \
+ i[3467]86*-*-freebsd[3-9]* | \
+ i[3467]86*-*-freebsd[12][0-9]*| \
+ i[3467]86*-*-freebsdelf* | \
+ i[3467]86*-*-netbsd* | \
i[3467]86*-*-k*bsd*)
echo '#define ELF_SYNTAX' >>./mpi/asm-syntax.h
cat $srcdir/mpi/i386/syntax.h >>./mpi/asm-syntax.h
@@ -64,6 +65,7 @@ case "${host}" in
i586*-*-openbsd* | \
i586*-*-freebsd*-elf | \
i586*-*-freebsd[3-9]* | \
+ i586*-*-freebsd[12][0-9]*| \
i586*-*-freebsdelf* | \
i586*-*-netbsd* | \
i586*-*-k*bsd* | \
--
2.1.4

@ -1 +1 @@
Fri, 09 Sep 2016 06:40:40 +0000
Fri, 09 Sep 2016 10:40:35 +0000

@ -1 +1 @@
Fri, 09 Sep 2016 06:40:40 +0000
Fri, 09 Sep 2016 10:40:35 +0000

@ -0,0 +1,13 @@
DEFINED_PHASES=configure install postinst prepare
DEPEND=pam? ( virtual/pam ) skey? ( >=sys-auth/skey-1.1.5-r1 ) ldap? ( >=net-nds/openldap-2.1.30-r1 dev-libs/cyrus-sasl ) sys-libs/zlib sys-devel/bison
DESCRIPTION=Allows users or groups to run commands as other users
EAPI=6
HOMEPAGE=http://www.sudo.ws/
IUSE=ldap nls pam offensive selinux skey +sendmail
LICENSE=ISC BSD
RDEPEND=pam? ( virtual/pam ) skey? ( >=sys-auth/skey-1.1.5-r1 ) ldap? ( >=net-nds/openldap-2.1.30-r1 dev-libs/cyrus-sasl ) sys-libs/zlib selinux? ( sec-policy/selinux-sudo ) ldap? ( dev-lang/perl ) pam? ( sys-auth/pambase ) >=app-misc/editor-wrapper-3 virtual/editor sendmail? ( virtual/mta )
REQUIRED_USE=pam? ( !skey ) skey? ( !pam )
SLOT=0
SRC_URI=http://www.sudo.ws/sudo/dist/beta/sudo-1.8.18rc1.tar.gz ftp://ftp.sudo.ws/pub/sudo/beta/sudo-1.8.18rc1.tar.gz
_eclasses_=eutils b83a2420b796f7c6eff682679d08fe25 flag-o-matic 8632fcd33a047954f007dee9a137bdcc libtool 4890219c51da247200223277f993e054 multilib 165fc17c38d1b11dac2008280dab6e80 pam 3ecd5b75e39b0bb05a3183c08fcdfdb4 toolchain-funcs 6198c04daba0e1307bd844df7d37f423
_md5_=ea220916e3884af338897d718523fa40

@ -0,0 +1,14 @@
DEFINED_PHASES=compile configure install postinst prepare setup unpack
DEPEND=>=dev-libs/glib-2.14:2 netlink? ( dev-libs/libnl:3 ) adns? ( >=net-dns/c-ares-1.5 ) crypt? ( dev-libs/libgcrypt:0 ) caps? ( sys-libs/libcap ) geoip? ( dev-libs/geoip ) gtk3? ( x11-libs/gdk-pixbuf x11-libs/pango x11-misc/xdg-utils x11-libs/gtk+:3 ) kerberos? ( virtual/krb5 ) lua? ( >=dev-lang/lua-5.1:* ) pcap? ( net-libs/libpcap ) portaudio? ( media-libs/portaudio ) qt4? ( dev-qt/qtcore:4 dev-qt/qtgui:4[accessibility] x11-misc/xdg-utils ) qt5? ( dev-qt/qtcore:5 dev-qt/qtgui:5 dev-qt/qtmultimedia:5 dev-qt/qtprintsupport:5 dev-qt/qtwidgets:5 x11-misc/xdg-utils ) sbc? ( media-libs/sbc ) smi? ( net-libs/libsmi ) ssl? ( net-libs/gnutls:= ) zlib? ( sys-libs/zlib !=sys-libs/zlib-1.2.4 ) dev-lang/perl !<virtual/perl-Pod-Simple-3.170 !<perl-core/Pod-Simple-3.170 doc? ( app-doc/doxygen app-text/asciidoc dev-libs/libxml2 dev-libs/libxslt doc-pdf? ( dev-java/fop ) www-client/lynx ) sys-devel/bison sys-devel/flex virtual/pkgconfig !<sys-devel/gettext-0.18.1.1-r3 || ( >=sys-devel/automake-1.15:1.15 ) >=sys-devel/autoconf-2.69 >=sys-devel/libtool-2.4 filecaps? ( sys-libs/libcap )
DESCRIPTION=A network protocol analyzer formerly known as ethereal
EAPI=5
HOMEPAGE=http://www.wireshark.org/
IUSE=adns androiddump +caps crypt doc doc-pdf geoip +gtk3 ipv6 kerberos lua +netlink +pcap portaudio +qt4 qt5 selinux sbc smi tfshark cpu_flags_x86_sse4_2 ssl zlib +filecaps
KEYWORDS=~alpha ~amd64 ~arm ~hppa ~ia64 ~ppc ~ppc64 ~sparc ~x86 ~x86-fbsd
LICENSE=GPL-2
RDEPEND=>=dev-libs/glib-2.14:2 netlink? ( dev-libs/libnl:3 ) adns? ( >=net-dns/c-ares-1.5 ) crypt? ( dev-libs/libgcrypt:0 ) caps? ( sys-libs/libcap ) geoip? ( dev-libs/geoip ) gtk3? ( x11-libs/gdk-pixbuf x11-libs/pango x11-misc/xdg-utils x11-libs/gtk+:3 ) kerberos? ( virtual/krb5 ) lua? ( >=dev-lang/lua-5.1:* ) pcap? ( net-libs/libpcap ) portaudio? ( media-libs/portaudio ) qt4? ( dev-qt/qtcore:4 dev-qt/qtgui:4[accessibility] x11-misc/xdg-utils ) qt5? ( dev-qt/qtcore:5 dev-qt/qtgui:5 dev-qt/qtmultimedia:5 dev-qt/qtprintsupport:5 dev-qt/qtwidgets:5 x11-misc/xdg-utils ) sbc? ( media-libs/sbc ) smi? ( net-libs/libsmi ) ssl? ( net-libs/gnutls:= ) zlib? ( sys-libs/zlib !=sys-libs/zlib-1.2.4 ) gtk3? ( virtual/freedesktop-icon-theme ) qt4? ( virtual/freedesktop-icon-theme ) qt5? ( virtual/freedesktop-icon-theme ) selinux? ( sec-policy/selinux-wireshark )
REQUIRED_USE=ssl? ( crypt ) ?? ( qt4 qt5 )
SLOT=0/2.0.6
SRC_URI=http://www.wireshark.org/download/src/all-versions/wireshark-2.0.6.tar.bz2
_eclasses_=autotools 07e71b3b5690738ef7e8bc097077e00c base 3fe4f8980633fd7bc69e9887209ba2fe eutils b83a2420b796f7c6eff682679d08fe25 fcaps 6a1091a98b1dde01cc26ab3252da1a9b flag-o-matic 8632fcd33a047954f007dee9a137bdcc libtool 4890219c51da247200223277f993e054 multilib 165fc17c38d1b11dac2008280dab6e80 qmake-utils 0a242e7177789b0028b4045f336dd4db qt4-r2 d6c113024bb3086a1facc65cd338930e toolchain-funcs 6198c04daba0e1307bd844df7d37f423 user 80aaa71614ced86f02ee1a513821dc87
_md5_=d4fd34e88f41e609e86adaccaff33c16

@ -11,4 +11,4 @@ REQUIRED_USE=acl? ( ads )
SLOT=0
SRC_URI=ftp://ftp.samba.org/pub/linux-cifs/cifs-utils/cifs-utils-6.4.tar.bz2
_eclasses_=eutils b83a2420b796f7c6eff682679d08fe25 linux-info fd1e29abbb02cbc49f1a14299846e9c4 multilib 165fc17c38d1b11dac2008280dab6e80 toolchain-funcs 6198c04daba0e1307bd844df7d37f423 versionator 99ae9d758cbe7cfed19170e7d48f5a9c
_md5_=cafa90cf5e4084f6a3ce9a83a09a008a
_md5_=79661381bfac2477d67d2e5486b2a78e

@ -11,4 +11,4 @@ REQUIRED_USE=acl? ( ads )
SLOT=0
SRC_URI=https://ftp.samba.org/pub/linux-cifs/cifs-utils/cifs-utils-6.5.tar.bz2
_eclasses_=eutils b83a2420b796f7c6eff682679d08fe25 linux-info fd1e29abbb02cbc49f1a14299846e9c4 multilib 165fc17c38d1b11dac2008280dab6e80 toolchain-funcs 6198c04daba0e1307bd844df7d37f423 versionator 99ae9d758cbe7cfed19170e7d48f5a9c
_md5_=2cce6c9b0de922ee4e457777ca9f2de3
_md5_=2c719bb6ba1aef3ce025bb176c468805

@ -11,4 +11,4 @@ REQUIRED_USE=acl? ( ads )
SLOT=0
SRC_URI=https://ftp.samba.org/pub/linux-cifs/cifs-utils/cifs-utils-6.6.tar.bz2
_eclasses_=eutils b83a2420b796f7c6eff682679d08fe25 linux-info fd1e29abbb02cbc49f1a14299846e9c4 multilib 165fc17c38d1b11dac2008280dab6e80 toolchain-funcs 6198c04daba0e1307bd844df7d37f423 versionator 99ae9d758cbe7cfed19170e7d48f5a9c
_md5_=2cce6c9b0de922ee4e457777ca9f2de3
_md5_=2c719bb6ba1aef3ce025bb176c468805

@ -0,0 +1,13 @@
DEFINED_PHASES=compile configure install prepare setup test
DEPEND=>=dev-libs/libtasn1-4.3[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/nettle-3.1:=[gmp,abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/gmp-5.1.3-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] tools? ( sys-devel/autogen ) crywrap? ( net-dns/libidn ) dane? ( >=net-dns/unbound-1.4.20[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) guile? ( >=dev-scheme/guile-1.8:*[networking] ) nls? ( >=virtual/libintl-0-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) pkcs11? ( >=app-crypt/p11-kit-0.23.1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) zlib? ( >=sys-libs/zlib-1.2.8-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) abi_x86_32? ( !<=app-emulation/emul-linux-x86-baselibs-20140508 !app-emulation/emul-linux-x86-baselibs[-abi_x86_32(-)] ) >=sys-devel/automake-1.11.6 >=virtual/pkgconfig-0-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] doc? ( sys-apps/texinfo dev-util/gtk-doc ) nls? ( sys-devel/gettext ) test? ( app-misc/datefudge ) !<sys-devel/gettext-0.18.1.1-r3 || ( >=sys-devel/automake-1.15:1.15 ) >=sys-devel/autoconf-2.69 >=sys-devel/libtool-2.4
DESCRIPTION=A TLS 1.2 and SSL 3.0 implementation for the GNU project
EAPI=6
HOMEPAGE=http://www.gnutls.org/
IUSE=+cxx +crywrap dane doc examples guile nls +openssl pkcs11 static-libs test +tls-heartbeat +tools zlib linguas_en linguas_cs linguas_de linguas_fi linguas_fr linguas_it linguas_ms linguas_nl linguas_pl linguas_sv linguas_uk linguas_vi linguas_zh_CN abi_x86_32 abi_x86_64 abi_x86_x32 abi_mips_n32 abi_mips_n64 abi_mips_o32 abi_ppc_32 abi_ppc_64 abi_s390_32 abi_s390_64
KEYWORDS=~alpha ~amd64 ~arm ~arm64 ~hppa ~ia64 ~m68k ~mips ~ppc ~ppc64 ~s390 ~sh ~sparc ~x86 ~amd64-fbsd ~sparc-fbsd ~x86-fbsd ~x86-interix ~amd64-linux ~arm-linux ~x86-linux ~ppc-macos ~x64-macos ~x86-macos ~sparc-solaris ~x86-solaris
LICENSE=GPL-3 LGPL-2.1
RDEPEND=>=dev-libs/libtasn1-4.3[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/nettle-3.1:=[gmp,abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/gmp-5.1.3-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] tools? ( sys-devel/autogen ) crywrap? ( net-dns/libidn ) dane? ( >=net-dns/unbound-1.4.20[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) guile? ( >=dev-scheme/guile-1.8:*[networking] ) nls? ( >=virtual/libintl-0-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) pkcs11? ( >=app-crypt/p11-kit-0.23.1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) zlib? ( >=sys-libs/zlib-1.2.8-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) abi_x86_32? ( !<=app-emulation/emul-linux-x86-baselibs-20140508 !app-emulation/emul-linux-x86-baselibs[-abi_x86_32(-)] )
SLOT=0/30
SRC_URI=mirror://gnupg/gnutls/v3.4/gnutls-3.4.15.tar.xz
_eclasses_=autotools 07e71b3b5690738ef7e8bc097077e00c eutils b83a2420b796f7c6eff682679d08fe25 libtool 4890219c51da247200223277f993e054 multibuild 742139c87a9fa3766f0c2b155e5522bf multilib 165fc17c38d1b11dac2008280dab6e80 multilib-build 8fe2e81aeb36cdf8a6cc5f50443879cc multilib-minimal 0224dee31c0f98405d572e14ad6dee65 toolchain-funcs 6198c04daba0e1307bd844df7d37f423 versionator 99ae9d758cbe7cfed19170e7d48f5a9c
_md5_=addcc46ff7262bc7c419cdd1db1c4568

@ -0,0 +1,13 @@
DEFINED_PHASES=compile configure install prepare setup test
DEPEND=>=dev-libs/libtasn1-4.3[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/nettle-3.1:=[gmp,abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/gmp-5.1.3-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] tools? ( sys-devel/autogen ) dane? ( >=net-dns/unbound-1.4.20[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) guile? ( >=dev-scheme/guile-1.8:*[networking] ) nls? ( >=virtual/libintl-0-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) pkcs11? ( >=app-crypt/p11-kit-0.23.1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) zlib? ( >=sys-libs/zlib-1.2.8-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) abi_x86_32? ( !<=app-emulation/emul-linux-x86-baselibs-20140508 !app-emulation/emul-linux-x86-baselibs[-abi_x86_32(-)] ) >=sys-devel/automake-1.11.6 >=virtual/pkgconfig-0-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] doc? ( sys-apps/texinfo dev-util/gtk-doc ) nls? ( sys-devel/gettext ) test? ( app-misc/datefudge ) !<sys-devel/gettext-0.18.1.1-r3 || ( >=sys-devel/automake-1.15:1.15 ) >=sys-devel/autoconf-2.69 >=sys-devel/libtool-2.4
DESCRIPTION=A TLS 1.2 and SSL 3.0 implementation for the GNU project
EAPI=6
HOMEPAGE=http://www.gnutls.org/
IUSE=+cxx dane doc examples guile nls +openssl pkcs11 sslv2 +sslv3 static-libs test +tls-heartbeat +tools zlib linguas_en linguas_cs linguas_de linguas_fi linguas_fr linguas_it linguas_ms linguas_nl linguas_pl linguas_sv linguas_uk linguas_vi linguas_zh_CN abi_x86_32 abi_x86_64 abi_x86_x32 abi_mips_n32 abi_mips_n64 abi_mips_o32 abi_ppc_32 abi_ppc_64 abi_s390_32 abi_s390_64
KEYWORDS=~alpha ~amd64 ~arm ~arm64 ~hppa ~ia64 ~m68k ~mips ~ppc ~ppc64 ~s390 ~sh ~sparc ~x86 ~amd64-fbsd ~sparc-fbsd ~x86-fbsd ~x86-interix ~amd64-linux ~arm-linux ~x86-linux ~ppc-macos ~x64-macos ~x86-macos ~sparc-solaris ~x86-solaris
LICENSE=GPL-3 LGPL-2.1
RDEPEND=>=dev-libs/libtasn1-4.3[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/nettle-3.1:=[gmp,abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] >=dev-libs/gmp-5.1.3-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] tools? ( sys-devel/autogen ) dane? ( >=net-dns/unbound-1.4.20[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) guile? ( >=dev-scheme/guile-1.8:*[networking] ) nls? ( >=virtual/libintl-0-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) pkcs11? ( >=app-crypt/p11-kit-0.23.1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) zlib? ( >=sys-libs/zlib-1.2.8-r1[abi_x86_32(-)?,abi_x86_64(-)?,abi_x86_x32(-)?,abi_mips_n32(-)?,abi_mips_n64(-)?,abi_mips_o32(-)?,abi_ppc_32(-)?,abi_ppc_64(-)?,abi_s390_32(-)?,abi_s390_64(-)?] ) abi_x86_32? ( !<=app-emulation/emul-linux-x86-baselibs-20140508 !app-emulation/emul-linux-x86-baselibs[-abi_x86_32(-)] )
SLOT=0/30
SRC_URI=mirror://gnupg/gnutls/v3.5/gnutls-3.5.4.tar.xz
_eclasses_=autotools 07e71b3b5690738ef7e8bc097077e00c eutils b83a2420b796f7c6eff682679d08fe25 libtool 4890219c51da247200223277f993e054 multibuild 742139c87a9fa3766f0c2b155e5522bf multilib 165fc17c38d1b11dac2008280dab6e80 multilib-build 8fe2e81aeb36cdf8a6cc5f50443879cc multilib-minimal 0224dee31c0f98405d572e14ad6dee65 toolchain-funcs 6198c04daba0e1307bd844df7d37f423 versionator 99ae9d758cbe7cfed19170e7d48f5a9c
_md5_=90c3e961ab85adc9546075d9d8387c3b

@ -10,4 +10,4 @@ RESTRICT=strip mirror
SLOT=22
SRC_URI=abi_x86_32? ( https://fpdownload.adobe.com/pub/flashplayer/pdc/22.0.0.209/flash_player_ppapi_linux.i386.tar.gz -> adobe-flash-22.0.0.209.i386.tar.gz ) abi_x86_64? ( https://fpdownload.adobe.com/pub/flashplayer/pdc/22.0.0.209/flash_player_ppapi_linux.x86_64.tar.gz -> adobe-flash-22.0.0.209.x86_64.tar.gz )
_eclasses_=multibuild 742139c87a9fa3766f0c2b155e5522bf multilib 165fc17c38d1b11dac2008280dab6e80 multilib-build 8fe2e81aeb36cdf8a6cc5f50443879cc multilib-minimal 0224dee31c0f98405d572e14ad6dee65 toolchain-funcs 6198c04daba0e1307bd844df7d37f423
_md5_=fba85b18c33bbda02b9ad40316049809
_md5_=4f86f4e70ec4e9f55d83da900584b5fc

@ -1 +1 @@
Fri, 09 Sep 2016 06:40:40 +0000
Fri, 09 Sep 2016 10:40:35 +0000

@ -1 +1 @@
Fri Sep 9 06:39:45 UTC 2016
Fri Sep 9 10:39:40 UTC 2016

@ -1 +1 @@
Fri, 09 Sep 2016 07:00:01 +0000
Fri, 09 Sep 2016 11:00:01 +0000

@ -1 +1 @@
1473403201 Fri 09 Sep 2016 06:40:01 AM UTC
1473417601 Fri 09 Sep 2016 10:40:01 AM UTC

@ -1 +1 @@
Fri, 09 Sep 2016 06:40:40 +0000
Fri, 09 Sep 2016 10:40:35 +0000

@ -1,3 +1,4 @@
DIST wireshark-2.0.4.tar.bz2 31121258 SHA256 9ea9c82da9942194ebc8fc5c951a02e6d179afa7472cb6d96ca76154510de1a5 SHA512 f86c41ba9fb25ea61f3947819676417f7af64301cdd37c91666d59b179c45d76c1d0e8739ef6bcf3bb077d3216a65458b3d56755dd08f1fb05cc87cb810f8a07 WHIRLPOOL 2a495221cc1e28283ca19c181fb531fbd01194dd9a0ce9ab6df2a50ce0e19dc21ff5fe023d08a88ebcbb2bfe2a55d47e173401bc09ff8f5356e695fb4cacb12b
DIST wireshark-2.0.5.tar.bz2 31124989 SHA256 0ce0241330828973f5b4efee422a3760cab8ce0b41e7721c4b9fd185be1bb10b SHA512 5b04165e1c18b30743ec6fc0bc81a02eb4906e87cbdc128da1e16662d855ed4a0545eb249aadba8a7e82b3abb4e1fdc5c56c06faaf730f56616332c0b7775e9c WHIRLPOOL 1f1a7dafa92c244534bd938f2b9290e33d6b2990a729a7e08aada81a3e935ccb93bbb42e0b952474b7d1c21588bf04057c40c2786ada1722f424a47dda8e192d
DIST wireshark-2.0.6.tar.bz2 31213641 SHA256 70f3ac4fbe6d3b51abe602f34f21b527a6819ca5017f4d1b27f963fc52c298db SHA512 2e4c9b76e365c6a2952b6a949173982286783884a60faaffb78a0364f606cb43811313ee31ada4c437cf831440253038d47976e5a1d73c3b1a85645691b1e5d9 WHIRLPOOL aa6570e5250c27ee3ac1ac9ea834102e0136f1482f702845b03aa4ab83fbcec64f8454fc9e9f6f92298e06208293c49a030f37d9dd6b569c3ed7c211e22eb5f5
DIST wireshark-2.2.0.tar.bz2 32141141 SHA256 a6847e741efcba6cb9d92d464d4219917bee3ad0b8f5b0f80d4388ad2f3f1104 SHA512 03dd1ce686b0e012d3498d6966382db1ff39844e2b03286eded5d77062a958d2dc939b00558708ae37b8e354d95ee6c4aa32023477d862b35bff4e2a0f8f3326 WHIRLPOOL bac335d03f919a079d3192af4e94998ee6a73e90e6f73512a3a5353b62af27967ebdf1d921689493d83315610f25cc8aeac62b8b4574aa3bb82d44e5275065c9

@ -0,0 +1,266 @@
# Copyright 1999-2016 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Id$
EAPI=5
inherit autotools eutils fcaps flag-o-matic multilib qmake-utils qt4-r2 user
DESCRIPTION="A network protocol analyzer formerly known as ethereal"
HOMEPAGE="http://www.wireshark.org/"
SRC_URI="${HOMEPAGE}download/src/all-versions/${P/_/}.tar.bz2"
LICENSE="GPL-2"
SLOT="0/${PV}"
KEYWORDS="~alpha ~amd64 ~arm ~hppa ~ia64 ~ppc ~ppc64 ~sparc ~x86 ~x86-fbsd"
IUSE="
adns androiddump +caps crypt doc doc-pdf geoip +gtk3 ipv6 kerberos lua
+netlink +pcap portaudio +qt4 qt5 selinux sbc smi tfshark
cpu_flags_x86_sse4_2 ssl zlib
"
REQUIRED_USE="
ssl? ( crypt )
?? ( qt4 qt5 )
"
S=${WORKDIR}/${P/_/}
GTK_COMMON_DEPEND="
x11-libs/gdk-pixbuf
x11-libs/pango
x11-misc/xdg-utils
"
CDEPEND="
>=dev-libs/glib-2.14:2
netlink? ( dev-libs/libnl:3 )
adns? ( >=net-dns/c-ares-1.5 )
crypt? ( dev-libs/libgcrypt:0 )
caps? ( sys-libs/libcap )
geoip? ( dev-libs/geoip )
gtk3? (
${GTK_COMMON_DEPEND}
x11-libs/gtk+:3
)
kerberos? ( virtual/krb5 )
lua? ( >=dev-lang/lua-5.1:* )
pcap? ( net-libs/libpcap )
portaudio? ( media-libs/portaudio )
qt4? (
dev-qt/qtcore:4
dev-qt/qtgui:4[accessibility]
x11-misc/xdg-utils
)
qt5? (
dev-qt/qtcore:5
dev-qt/qtgui:5
dev-qt/qtmultimedia:5
dev-qt/qtprintsupport:5
dev-qt/qtwidgets:5
x11-misc/xdg-utils
)
sbc? ( media-libs/sbc )
smi? ( net-libs/libsmi )
ssl? ( net-libs/gnutls:= )
zlib? ( sys-libs/zlib !=sys-libs/zlib-1.2.4 )
"
# We need perl for `pod2html`. The rest of the perl stuff is to block older
# and broken installs. #455122
DEPEND="
${CDEPEND}
dev-lang/perl
!<virtual/perl-Pod-Simple-3.170
!<perl-core/Pod-Simple-3.170
doc? (
app-doc/doxygen
app-text/asciidoc
dev-libs/libxml2
dev-libs/libxslt
doc-pdf? ( dev-java/fop )
www-client/lynx
)
sys-devel/bison
sys-devel/flex
virtual/pkgconfig
"
RDEPEND="
${CDEPEND}
gtk3? ( virtual/freedesktop-icon-theme )
qt4? ( virtual/freedesktop-icon-theme )
qt5? ( virtual/freedesktop-icon-theme )
selinux? ( sec-policy/selinux-wireshark )
"
pkg_setup() {
enewgroup wireshark
}
src_prepare() {
epatch \
"${FILESDIR}"/${PN}-1.6.13-ldflags.patch \
"${FILESDIR}"/${PN}-1.11.0-oldlibs.patch \
"${FILESDIR}"/${PN}-99999999-pkgconfig.patch \
"${FILESDIR}"/${PN}-1.99.8-qtchooser.patch \
"${FILESDIR}"/${PN}-2.0.0-androiddump-pcap.patch \
"${FILESDIR}"/${PN}-2.1.0-sse4_2.patch
epatch_user
eautoreconf
}
src_configure() {
local myconf
# Workaround bug #213705. If krb5-config --libs has -lcrypto then pass
# --with-ssl to ./configure. (Mimics code from acinclude.m4).
if use kerberos; then
case $(krb5-config --libs) in
*-lcrypto*)
ewarn "Kerberos was built with ssl support: linkage with openssl is enabled."
ewarn "Note there are annoying license incompatibilities between the OpenSSL"
ewarn "license and the GPL, so do your check before distributing such package."
myconf+=( "--with-ssl" )
;;
esac
fi
# Enable wireshark binary with any supported GUI toolkit (bug #473188)
if use gtk3 || use qt4 || use qt5; then
myconf+=( "--enable-wireshark" )
else
myconf+=( "--disable-wireshark" )
fi
if ! use qt4 && ! use qt5; then
myconf+=( "--with-qt=no" )
fi
if use qt4; then
export QT_MIN_VERSION=4.6.0
fi
if use qt5; then
export QT_MIN_VERSION=5.3.0
append-cxxflags -fPIC -DPIC
fi
# Hack around inability to disable doxygen/fop doc generation
use doc || export ac_cv_prog_HAVE_DOXYGEN=false
use doc-pdf || export ac_cv_prog_HAVE_FOP=false
# dumpcap requires libcap
# --disable-profile-build bugs #215806, #292991, #479602
econf \
$(use androiddump && use pcap && echo --enable-androiddump-use-libpcap=yes) \
$(use_enable androiddump) \
$(use_enable ipv6) \
$(use_enable tfshark) \
$(use_with adns c-ares) \
$(use_with caps libcap) \
$(use_with crypt gcrypt) \
$(use_with geoip) \
$(use_with gtk3) \
$(use_with kerberos krb5) \
$(use_with lua) \
$(use_with pcap dumpcap-group wireshark) \
$(use_with pcap) \
$(use_with portaudio) \
$(usex qt4 --with-qt=4 '') \
$(usex qt5 --with-qt=5 '') \
$(usex qt4 MOC=$(qt4_get_bindir)/moc '') \
$(usex qt4 RCC=$(qt4_get_bindir)/rcc '') \
$(usex qt4 UIC=$(qt4_get_bindir)/uic '') \
$(usex qt5 MOC=$(qt5_get_bindir)/moc '') \
$(usex qt5 RCC=$(qt5_get_bindir)/rcc '') \
$(usex qt5 UIC=$(qt5_get_bindir)/uic '') \
$(use_with sbc) \
$(use_with smi libsmi) \
$(use_with ssl gnutls) \
$(use_with zlib) \
$(usex netlink --with-libnl=3 --without-libnl) \
$(usex cpu_flags_x86_sse4_2 --enable-sse4_2 '') \
--disable-profile-build \
--disable-usr-local \
--disable-warnings-as-errors \
--sysconfdir="${EPREFIX}"/etc/wireshark \
--without-adns \
${myconf[@]}
}
src_compile() {
default
if use doc; then
use doc-pdf && addpredict "/root/.java"
emake -j1 -C docbook
fi
}
src_install() {
default
if use doc; then
dohtml -r docbook/{release-notes.html,ws{d,u}g_html{,_chunked}}
if use doc-pdf; then
insinto /usr/share/doc/${PF}/pdf/
doins docbook/{developer,user}-guide-{a4,us}.pdf docbook/release-notes.pdf
fi
fi
# FAQ is not required as is installed from help/faq.txt
dodoc AUTHORS ChangeLog NEWS README{,.bsd,.linux,.macos,.vmware} \
doc/{randpkt.txt,README*}
# install headers
local wsheader
for wsheader in \
color.h \
config.h \
epan/*.h \
epan/crypt/*.h \
epan/dfilter/*.h \
epan/dissectors/*.h \
epan/ftypes/*.h \
epan/wmem/*.h \
register.h \
wiretap/*.h \
ws_symbol_export.h \
wsutil/*.h
do
insinto /usr/include/wireshark/$( dirname ${wsheader} )
doins ${wsheader}
done
#with the above this really shouldn't be needed, but things may be looking in wiretap/ instead of wireshark/wiretap/
insinto /usr/include/wiretap
doins wiretap/wtap.h
if use gtk3 || use qt4 || use qt5; then
local c d
for c in hi lo; do
for d in 16 32 48; do
insinto /usr/share/icons/${c}color/${d}x${d}/apps
newins image/${c}${d}-app-wireshark.png wireshark.png
done
done
for d in 16 24 32 48 64 128 256 ; do
insinto /usr/share/icons/hicolor/${d}x${d}/mimetypes
newins image/WiresharkDoc-${d}.png application-vnd.tcpdump.pcap.png
done
fi
prune_libtool_files
}
pkg_postinst() {
# Add group for users allowed to sniff.
enewgroup wireshark
if use pcap; then
fcaps -o 0 -g wireshark -m 4710 -M 0710 \
cap_dac_read_search,cap_net_raw,cap_net_admin \
"${EROOT}"/usr/bin/dumpcap
fi
ewarn "NOTE: To capture traffic with wireshark as normal user you have to"
ewarn "add yourself to the wireshark group. This security measure ensures"
ewarn "that only trusted users are allowed to sniff your traffic."
}

@ -81,6 +81,8 @@ src_install() {
dodir /etc/request-key.d
echo 'create dns_resolver * * /usr/sbin/cifs.upcall %k' \
> "${ED}/etc/request-key.d/cifs.upcall.conf"
echo 'create cifs.spnego * * /usr/sbin/cifs.upcall %k' \
> "${ED}/etc/request-key.d/cifs.spnego.conf"
fi
}

@ -81,6 +81,8 @@ src_install() {
dodir /etc/request-key.d
echo 'create dns_resolver * * /usr/sbin/cifs.upcall %k' \
> "${ED}/etc/request-key.d/cifs.upcall.conf"
echo 'create cifs.spnego * * /usr/sbin/cifs.upcall %k' \
> "${ED}/etc/request-key.d/cifs.spnego.conf"
fi
}

@ -81,6 +81,8 @@ src_install() {
dodir /etc/request-key.d
echo 'create dns_resolver * * /usr/sbin/cifs.upcall %k' \
> "${ED}/etc/request-key.d/cifs.upcall.conf"
echo 'create cifs.spnego * * /usr/sbin/cifs.upcall %k' \
> "${ED}/etc/request-key.d/cifs.spnego.conf"
fi
}

@ -2,4 +2,6 @@ DIST gnutls-3.3.17.1.tar.xz 6339588 SHA256 b40f158030a92f450a07b20300a3996710ca1
DIST gnutls-3.3.23.tar.xz 6304332 SHA256 f53453857e369d66d665c40389201c0b9dacb7ccda560fd21b20b798687a4239 SHA512 5c2e93ddbff3ca2fc5f8fca8eeaef363bf8fe0f5dce2f4a9448e3235c930baa09d59a456a019283a451d19e0497d3ae645786080aa31febc7f1bcd71c6de1e09 WHIRLPOOL fa082db1933eefc7e061dc7f7e6584d03920f40584865e2983250097db9acea0e6d0c075e8207a2e5b96e37ae77db2b91bcf21e97cc7dfdec0744904de4b5866
DIST gnutls-3.3.24.tar.xz 6294532 SHA256 5b65fe2a91c8dfa32bedc78acffcb152e5426cd3349e2afc43cccc9bdaf18aa5 SHA512 1fbb2e15ade14db15d7acc9ff559ecfc39517fd99e6c784583a7a4f8786daf8053f35f41e39cde0eeb5a1dfd3193ad908b52f62f945fbd43c147dc87e55f192f WHIRLPOOL 0725b35af9bbb4a7ee8f430af95e078066fb455328dd0ee71cca6633d093fe0433c7d869ebf0fabf8983679a32ff8451a2b631aec672810eb7bc55a3de28cc7d
DIST gnutls-3.4.14.tar.xz 6673148 SHA256 35deddf2779b76ac11057de38bf380b8066c05de21b94263ad5b6dfa75dfbb23 SHA512 d75f6b4dea2dc742cd7f60ee0ee540d41b69991aaa937ca0138cfdf4a1e0dfaaa3863464303bfa5799e14ee02de252f71c59a7a9e57b96ff8af653e419edfd4e WHIRLPOOL 1869b831521f4ef5dde5a6694fdf6239793b404478a9b7e97ec2b4af2f1a4326fa5b65521a74d664113a84d2ff1b660269fcf1f3ca1db361fddfab2af3c191dd
DIST gnutls-3.4.15.tar.xz 6676480 SHA256 eb2a013905f5f2a0cbf7bcc1d20c85a50065063ee87bd33b496c4e19815e3498 SHA512 03157f2da22890ecd080ad58144a9aabe933382c0b7e969b7b194a0248bb5e6e25207078c0a92755650d0004970eb1c0cf0140dbdbf2e615808f9978e965a5e5 WHIRLPOOL a5f866e44421b6ecb492587f9eee09373fbda0644cc71468995fd2756b620c254c2cd69c07e8db30df415810d1090daf5ea5d50b33f2fda02c0758a7d4ee04e8
DIST gnutls-3.5.3.tar.xz 6895068 SHA256 92c4bc999a10a1b95299ebefaeea8333f19d8a98d957a35b5eae74881bdb1fef SHA512 d53d8067628ce49e5bb0dbbd76761a27f585b0a38356c0d8524db6cf96542f54a7f8a87c5772335c1ca1ceec1e111e11c54636bb24ca2ac014c367b96c9e3969 WHIRLPOOL fc0b7a744c6c08a48c43a2e95781ec7139600b45b12f8352db01824468f301ab56f2adfec6f7a4806247fe33eadaa234ad541a27c75d8689c2817a0f5967aa05
DIST gnutls-3.5.4.tar.xz 6930620 SHA256 4e38014332e0f70c5d19b0eca8d85025ccd0d8be85894c0aaa498b42f6b9a8eb SHA512 175aab43b6349a62530938333910feb26ea5d923e151a9942fd5a6989f87193b18862e69bbbdb6308f889585d428d689d8fd3a6e8149f9fd1ac2882802ea6a9f WHIRLPOOL 6625adb815a69ba24e19b7966884f36577e8035272884d3d3b38c813ddd73e211ec3d2180c4e9160ad8459acab0ee72a36b328eae27357d6d1eb6476a06db75a

@ -0,0 +1,132 @@
# Copyright 1999-2016 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Id$
EAPI=6
inherit autotools libtool eutils multilib-minimal versionator
DESCRIPTION="A TLS 1.2 and SSL 3.0 implementation for the GNU project"
HOMEPAGE="http://www.gnutls.org/"
SRC_URI="mirror://gnupg/gnutls/v$(get_version_component_range 1-2)/${P}.tar.xz"
LICENSE="GPL-3 LGPL-2.1"
SLOT="0/30" # libgnutls.so number
KEYWORDS="~alpha ~amd64 ~arm ~arm64 ~hppa ~ia64 ~m68k ~mips ~ppc ~ppc64 ~s390 ~sh ~sparc ~x86 ~amd64-fbsd ~sparc-fbsd ~x86-fbsd ~x86-interix ~amd64-linux ~arm-linux ~x86-linux ~ppc-macos ~x64-macos ~x86-macos ~sparc-solaris ~x86-solaris"
IUSE_LINGUAS=" en cs de fi fr it ms nl pl sv uk vi zh_CN"
IUSE="+cxx +crywrap dane doc examples guile nls +openssl pkcs11 static-libs test +tls-heartbeat +tools zlib ${IUSE_LINGUAS// / linguas_}"
# NOTICE: sys-devel/autogen is required at runtime as we
# use system libopts
RDEPEND=">=dev-libs/libtasn1-4.3[${MULTILIB_USEDEP}]
>=dev-libs/nettle-3.1:=[gmp,${MULTILIB_USEDEP}]
>=dev-libs/gmp-5.1.3-r1[${MULTILIB_USEDEP}]
tools? ( sys-devel/autogen )
crywrap? ( net-dns/libidn )
dane? ( >=net-dns/unbound-1.4.20[${MULTILIB_USEDEP}] )
guile? ( >=dev-scheme/guile-1.8:*[networking] )
nls? ( >=virtual/libintl-0-r1[${MULTILIB_USEDEP}] )
pkcs11? ( >=app-crypt/p11-kit-0.23.1[${MULTILIB_USEDEP}] )
zlib? ( >=sys-libs/zlib-1.2.8-r1[${MULTILIB_USEDEP}] )
abi_x86_32? (
!<=app-emulation/emul-linux-x86-baselibs-20140508
!app-emulation/emul-linux-x86-baselibs[-abi_x86_32(-)]
)"
DEPEND="${RDEPEND}
>=sys-devel/automake-1.11.6
>=virtual/pkgconfig-0-r1[${MULTILIB_USEDEP}]
doc? (
sys-apps/texinfo
dev-util/gtk-doc
)
nls? ( sys-devel/gettext )
test? ( app-misc/datefudge )"
DOCS=( AUTHORS ChangeLog NEWS README THANKS doc/TODO )
PATCHES=(
"${FILESDIR}/${PN}-3.4.7-build-allow-installing-man-1-even-with-disable-doc.patch"
)
pkg_setup() {
# bug#520818
export TZ=UTC
}
src_prepare() {
default
sed -i \
-e 's/imagesdir = $(infodir)/imagesdir = $(htmldir)/' \
doc/Makefile.am || die
# force regeneration of autogen-ed files
local file
for file in $(grep -l AutoGen-ed src/*.c) ; do
rm src/$(basename ${file} .c).{c,h} || die
done
# force regeneration of makeinfo files
# have no idea why on some system these files are not
# accepted as-is, see bug#520818
for file in $(grep -l "produced by makeinfo" doc/*.info) ; do
rm "${file}" || die
done
eautoreconf
# Use sane .so versioning on FreeBSD.
elibtoolize
# bug 497472
use cxx || epunt_cxx
}
multilib_src_configure() {
LINGUAS="${LINGUAS//en/en@boldquot en@quot}"
# TPM needs to be tested before being enabled
# hardware-accell is disabled on OSX because the asm files force
# GNU-stack (as doesn't support that) and when that's removed ld
# complains about duplicate symbols
ECONF_SOURCE=${S} \
econf \
--disable-valgrind-tests \
--without-included-libtasn1 \
$(use_enable cxx) \
$(use_enable dane libdane) \
$(multilib_native_enable manpages) \
$(multilib_native_use_enable tools) \
$(multilib_native_use_enable doc) \
$(multilib_native_use_enable doc gtk-doc) \
$(multilib_native_use_enable guile) \
$(multilib_native_use_enable crywrap) \
$(multilib_native_use_enable test tests) \
$(use_enable nls) \
$(use_enable openssl openssl-compatibility) \
$(use_enable tls-heartbeat heartbeat-support) \
$(use_enable static-libs static) \
$(use_with pkcs11 p11-kit) \
$(use_with zlib) \
--without-tpm \
--with-unbound-root-key-file=/etc/dnssec/root-anchors.txt \
$([[ ${CHOST} == *-darwin* ]] && echo --disable-hardware-acceleration)
}
multilib_src_install_all() {
einstalldocs
prune_libtool_files --all
dodoc doc/certtool.cfg
if use doc; then
dohtml doc/gnutls.html
else
rm -fr "${ED}/usr/share/doc/${PF}/html"
fi
if use examples; then
docinto examples
dodoc doc/examples/*.c
fi
}

@ -0,0 +1,126 @@
# Copyright 1999-2016 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Id$
EAPI=6
inherit autotools libtool eutils multilib-minimal versionator
DESCRIPTION="A TLS 1.2 and SSL 3.0 implementation for the GNU project"
HOMEPAGE="http://www.gnutls.org/"
SRC_URI="mirror://gnupg/gnutls/v$(get_version_component_range 1-2)/${P}.tar.xz"
LICENSE="GPL-3 LGPL-2.1"
SLOT="0/30" # libgnutls.so number
KEYWORDS="~alpha ~amd64 ~arm ~arm64 ~hppa ~ia64 ~m68k ~mips ~ppc ~ppc64 ~s390 ~sh ~sparc ~x86 ~amd64-fbsd ~sparc-fbsd ~x86-fbsd ~x86-interix ~amd64-linux ~arm-linux ~x86-linux ~ppc-macos ~x64-macos ~x86-macos ~sparc-solaris ~x86-solaris"
IUSE_LINGUAS=" en cs de fi fr it ms nl pl sv uk vi zh_CN"
IUSE="+cxx dane doc examples guile nls +openssl pkcs11 sslv2 +sslv3 static-libs test +tls-heartbeat +tools zlib ${IUSE_LINGUAS// / linguas_}"
# NOTICE: sys-devel/autogen is required at runtime as we
# use system libopts
RDEPEND=">=dev-libs/libtasn1-4.3[${MULTILIB_USEDEP}]
>=dev-libs/nettle-3.1:=[gmp,${MULTILIB_USEDEP}]
>=dev-libs/gmp-5.1.3-r1[${MULTILIB_USEDEP}]
tools? ( sys-devel/autogen )
dane? ( >=net-dns/unbound-1.4.20[${MULTILIB_USEDEP}] )
guile? ( >=dev-scheme/guile-1.8:*[networking] )
nls? ( >=virtual/libintl-0-r1[${MULTILIB_USEDEP}] )
pkcs11? ( >=app-crypt/p11-kit-0.23.1[${MULTILIB_USEDEP}] )
zlib? ( >=sys-libs/zlib-1.2.8-r1[${MULTILIB_USEDEP}] )
abi_x86_32? (
!<=app-emulation/emul-linux-x86-baselibs-20140508
!app-emulation/emul-linux-x86-baselibs[-abi_x86_32(-)]
)"
DEPEND="${RDEPEND}
>=sys-devel/automake-1.11.6
>=virtual/pkgconfig-0-r1[${MULTILIB_USEDEP}]
doc? (
sys-apps/texinfo
dev-util/gtk-doc
)
nls? ( sys-devel/gettext )
test? ( app-misc/datefudge )"
pkg_setup() {
# bug#520818
export TZ=UTC
}
src_prepare() {
default
sed -i \
-e 's/imagesdir = $(infodir)/imagesdir = $(htmldir)/' \
doc/Makefile.am || die
# force regeneration of autogen-ed files
local file
for file in $(grep -l AutoGen-ed src/*.c) ; do
rm src/$(basename ${file} .c).{c,h} || die
done
# force regeneration of makeinfo files
# have no idea why on some system these files are not
# accepted as-is, see bug#520818
for file in $(grep -l "produced by makeinfo" doc/*.info) ; do
rm "${file}" || die
done
eautoreconf
# Use sane .so versioning on FreeBSD.
elibtoolize
# bug 497472
use cxx || epunt_cxx
}
multilib_src_configure() {
LINGUAS="${LINGUAS//en/en@boldquot en@quot}"
# TPM needs to be tested before being enabled
# hardware-accell is disabled on OSX because the asm files force
# GNU-stack (as doesn't support that) and when that's removed ld
# complains about duplicate symbols
ECONF_SOURCE=${S} \
econf \
--disable-valgrind-tests \
--without-included-libtasn1 \
$(use_enable cxx) \
$(use_enable dane libdane) \
$(multilib_native_enable manpages) \
$(multilib_native_use_enable tools) \
$(multilib_native_use_enable doc) \
$(multilib_native_use_enable doc gtk-doc) \
$(multilib_native_use_enable guile) \
$(multilib_native_use_enable test tests) \
$(use_enable nls) \
$(use_enable openssl openssl-compatibility) \
$(use_enable tls-heartbeat heartbeat-support) \
$(use_enable sslv2 ssl2-support) \
$(use_enable sslv3 ssl3-support) \
$(use_enable static-libs static) \
$(use_with pkcs11 p11-kit) \
$(use_with zlib) \
--without-tpm \
--with-unbound-root-key-file=/etc/dnssec/root-anchors.txt \
$([[ ${CHOST} == *-darwin* ]] && echo --disable-hardware-acceleration)
}
multilib_src_install_all() {
einstalldocs
prune_libtool_files --all
dodoc doc/certtool.cfg
if use doc; then
dohtml doc/gnutls.html
else
rm -fr "${ED}/usr/share/doc/${PF}/html"
fi
if use examples; then
docinto examples
dodoc doc/examples/*.c
fi
}

@ -1,5 +1,5 @@
diff --git a/cipher-ctr-mt.c b/cipher-ctr-mt.c
index fdc9b2f..0b35881 100644
index fdc9b2f..3ffe6d1 100644
--- a/cipher-ctr-mt.c
+++ b/cipher-ctr-mt.c
@@ -127,7 +127,7 @@ struct kq {
@ -11,23 +11,27 @@ index fdc9b2f..0b35881 100644
pthread_mutex_t lock;
pthread_cond_t cond;
u_char pad1[CACHELINE_LEN];
@@ -141,6 +141,9 @@ struct ssh_aes_ctr_ctx
@@ -141,6 +141,11 @@ struct ssh_aes_ctr_ctx
STATS_STRUCT(stats);
u_char aes_counter[AES_BLOCK_SIZE];
pthread_t tid[CIPHER_THREADS];
+ pthread_rwlock_t tid_lock;
+#ifdef __APPLE__
+ pthread_rwlock_t stop_lock;
+ int exit_flag;
+#endif /* __APPLE__ */
int state;
int qidx;
int ridx;
@@ -187,6 +190,23 @@ thread_loop_cleanup(void *x)
@@ -187,6 +192,57 @@ thread_loop_cleanup(void *x)
pthread_mutex_unlock((pthread_mutex_t *)x);
}
+#ifdef __APPLE__
+/* Check if we should exit, we are doing both cancel and exit condition
+ * since OSX seems to misbehave with cancel sometimes, so we want to have
+ * a backup to make sure that everything exits properly
+ * since on OSX threads seem to occasionally fail to notice when they have
+ * been cancelled. We want to have a backup to make sure that we won't hang
+ * when the main process join()-s the cancelled thread.
+ */
+static void
+thread_loop_check_exit(struct ssh_aes_ctr_ctx *c)
@ -38,14 +42,46 @@ index fdc9b2f..0b35881 100644
+ exit_flag = c->exit_flag;
+ pthread_rwlock_unlock(&c->stop_lock);
+
+ if (exit_flag == TRUE)
+ if (exit_flag)
+ pthread_exit(NULL);
+}
+#else
+# define thread_loop_check_exit(s)
+#endif /* __APPLE__ */
+
+/*
+ * Helper function to terminate the helper threads
+ */
+static void
+stop_and_join_pregen_threads(struct ssh_aes_ctr_ctx *c)
+{
+ int i;
+
+#ifdef __APPLE__
+ /* notify threads that they should exit */
+ pthread_rwlock_wrlock(&c->stop_lock);
+ c->exit_flag = TRUE;
+ pthread_rwlock_unlock(&c->stop_lock);
+#endif /* __APPLE__ */
+
+ /* Cancel pregen threads */
+ for (i = 0; i < CIPHER_THREADS; i++) {
+ pthread_cancel(c->tid[i]);
+ }
+ for (i = 0; i < NUMKQ; i++) {
+ pthread_mutex_lock(&c->q[i].lock);
+ pthread_cond_broadcast(&c->q[i].cond);
+ pthread_mutex_unlock(&c->q[i].lock);
+ }
+ for (i = 0; i < CIPHER_THREADS; i++) {
+ pthread_join(c->tid[i], NULL);
+ }
+}
+
/*
* The life of a pregen thread:
* Find empty keystream queues and fill them using their counter.
@@ -201,6 +221,7 @@ thread_loop(void *x)
@@ -201,6 +257,7 @@ thread_loop(void *x)
struct kq *q;
int i;
int qidx;
@ -53,7 +89,7 @@ index fdc9b2f..0b35881 100644
/* Threads stats on cancellation */
STATS_INIT(stats);
@@ -211,11 +232,15 @@ thread_loop(void *x)
@@ -211,11 +268,15 @@ thread_loop(void *x)
/* Thread local copy of AES key */
memcpy(&key, &c->aes_ctx, sizeof(key));
@ -70,7 +106,7 @@ index fdc9b2f..0b35881 100644
q = &c->q[0];
pthread_mutex_lock(&q->lock);
if (q->qstate == KQINIT) {
@@ -245,12 +270,16 @@ thread_loop(void *x)
@@ -245,12 +306,16 @@ thread_loop(void *x)
/* Check if I was cancelled, also checked in cond_wait */
pthread_testcancel();
@ -87,7 +123,7 @@ index fdc9b2f..0b35881 100644
pthread_cond_wait(&q->cond, &q->lock);
}
pthread_cleanup_pop(0);
@@ -268,6 +297,7 @@ thread_loop(void *x)
@@ -268,6 +333,7 @@ thread_loop(void *x)
* can see that it's being filled.
*/
q->qstate = KQFILLING;
@ -95,7 +131,7 @@ index fdc9b2f..0b35881 100644
pthread_mutex_unlock(&q->lock);
for (i = 0; i < KQLEN; i++) {
AES_encrypt(q->ctr, q->keys[i], &key);
@@ -279,7 +309,7 @@ thread_loop(void *x)
@@ -279,7 +345,7 @@ thread_loop(void *x)
ssh_ctr_add(q->ctr, KQLEN * (NUMKQ - 1), AES_BLOCK_SIZE);
q->qstate = KQFULL;
STATS_FILL(stats);
@ -104,7 +140,7 @@ index fdc9b2f..0b35881 100644
pthread_mutex_unlock(&q->lock);
}
@@ -371,6 +401,7 @@ ssh_aes_ctr(EVP_CIPHER_CTX *ctx, u_char *dest, const u_char *src,
@@ -371,6 +437,7 @@ ssh_aes_ctr(EVP_CIPHER_CTX *ctx, u_char *dest, const u_char *src,
pthread_cond_wait(&q->cond, &q->lock);
}
q->qstate = KQDRAINING;
@ -112,40 +148,34 @@ index fdc9b2f..0b35881 100644
pthread_mutex_unlock(&q->lock);
/* Mark consumed queue empty and signal producers */
@@ -397,6 +428,9 @@ ssh_aes_ctr_init(EVP_CIPHER_CTX *ctx, const u_char *key, const u_char *iv,
@@ -397,6 +464,11 @@ ssh_aes_ctr_init(EVP_CIPHER_CTX *ctx, const u_char *key, const u_char *iv,
if ((c = EVP_CIPHER_CTX_get_app_data(ctx)) == NULL) {
c = xmalloc(sizeof(*c));
+ pthread_rwlock_init(&c->tid_lock, NULL);
+#ifdef __APPLE__
+ pthread_rwlock_init(&c->stop_lock, NULL);
+ c->exit_flag = FALSE;
+#endif /* __APPLE__ */
c->state = HAVE_NONE;
for (i = 0; i < NUMKQ; i++) {
@@ -409,11 +443,22 @@ ssh_aes_ctr_init(EVP_CIPHER_CTX *ctx, const u_char *key, const u_char *iv,
@@ -409,11 +481,9 @@ ssh_aes_ctr_init(EVP_CIPHER_CTX *ctx, const u_char *key, const u_char *iv,
}
if (c->state == (HAVE_KEY | HAVE_IV)) {
- /* Cancel pregen threads */
- for (i = 0; i < CIPHER_THREADS; i++)
- pthread_cancel(c->tid[i]);
- for (i = 0; i < CIPHER_THREADS; i++)
- pthread_join(c->tid[i], NULL);
+ /* tell the pregen threads to exit */
+ pthread_rwlock_wrlock(&c->stop_lock);
+ c->exit_flag = TRUE;
+ pthread_rwlock_unlock(&c->stop_lock);
+
/* Cancel pregen threads */
for (i = 0; i < CIPHER_THREADS; i++)
pthread_cancel(c->tid[i]);
+ for (i = 0; i < NUMKQ; i++) {
+ pthread_mutex_lock(&c->q[i].lock);
+ pthread_cond_broadcast(&c->q[i].cond);
+ pthread_mutex_unlock(&c->q[i].lock);
+ }
for (i = 0; i < CIPHER_THREADS; i++)
pthread_join(c->tid[i], NULL);
+ stop_and_join_pregen_threads(c);
+
/* Start over getting key & iv */
c->state = HAVE_NONE;
}
@@ -444,10 +489,12 @@ ssh_aes_ctr_init(EVP_CIPHER_CTX *ctx, const u_char *key, const u_char *iv,
@@ -444,10 +514,12 @@ ssh_aes_ctr_init(EVP_CIPHER_CTX *ctx, const u_char *key, const u_char *iv,
/* Start threads */
for (i = 0; i < CIPHER_THREADS; i++) {
debug("spawned a thread");
@ -159,29 +189,26 @@ index fdc9b2f..0b35881 100644
pthread_cond_wait(&c->q[0].cond, &c->q[0].lock);
pthread_mutex_unlock(&c->q[0].lock);
}
@@ -463,10 +510,21 @@ ssh_aes_ctr_thread_destroy(EVP_CIPHER_CTX *ctx)
@@ -461,15 +533,10 @@ void
ssh_aes_ctr_thread_destroy(EVP_CIPHER_CTX *ctx)
{
struct ssh_aes_ctr_ctx *c;
int i;
c = EVP_CIPHER_CTX_get_app_data(ctx);
- int i;
+
+ /* notify threads that they should exit */
+ pthread_rwlock_wrlock(&c->stop_lock);
+ c->exit_flag = TRUE;
+ pthread_rwlock_unlock(&c->stop_lock);
c = EVP_CIPHER_CTX_get_app_data(ctx);
- /* destroy threads */
- for (i = 0; i < CIPHER_THREADS; i++) {
- pthread_cancel(c->tid[i]);
- }
- for (i = 0; i < CIPHER_THREADS; i++) {
- pthread_join(c->tid[i], NULL);
- }
+
/* destroy threads */
for (i = 0; i < CIPHER_THREADS; i++) {
pthread_cancel(c->tid[i]);
}
+ for (i = 0; i < NUMKQ; i++) {
+ pthread_mutex_lock(&c->q[i].lock);
+ pthread_cond_broadcast(&c->q[i].cond);
+ pthread_mutex_unlock(&c->q[i].lock);
+ }
for (i = 0; i < CIPHER_THREADS; i++) {
pthread_join(c->tid[i], NULL);
}
@@ -481,7 +539,9 @@ ssh_aes_ctr_thread_reconstruction(EVP_CIPHER_CTX *ctx)
+ stop_and_join_pregen_threads(c);
}
void
@@ -481,7 +548,9 @@ ssh_aes_ctr_thread_reconstruction(EVP_CIPHER_CTX *ctx)
/* reconstruct threads */
for (i = 0; i < CIPHER_THREADS; i++) {
debug("spawned a thread");
@ -191,23 +218,23 @@ index fdc9b2f..0b35881 100644
}
}
@@ -496,9 +556,19 @@ ssh_aes_ctr_cleanup(EVP_CIPHER_CTX *ctx)
@@ -489,18 +558,13 @@ static int
ssh_aes_ctr_cleanup(EVP_CIPHER_CTX *ctx)
{
struct ssh_aes_ctr_ctx *c;
- int i;
if ((c = EVP_CIPHER_CTX_get_app_data(ctx)) != NULL) {
#ifdef CIPHER_THREAD_STATS
debug("main thread: %u drains, %u waits", c->stats.drains,
c->stats.waits);
#endif
+ /* tell the pregen threads to exit */
+ pthread_rwlock_wrlock(&c->stop_lock);
+ c->exit_flag = TRUE;
+ pthread_rwlock_unlock(&c->stop_lock);
+
/* Cancel pregen threads */
for (i = 0; i < CIPHER_THREADS; i++)
pthread_cancel(c->tid[i]);
+ for (i = 0; i < NUMKQ; i++) {
+ pthread_mutex_lock(&c->q[i].lock);
+ pthread_cond_broadcast(&c->q[i].cond);
+ pthread_mutex_unlock(&c->q[i].lock);
+ }
for (i = 0; i < CIPHER_THREADS; i++)
pthread_join(c->tid[i], NULL);
- /* Cancel pregen threads */
- for (i = 0; i < CIPHER_THREADS; i++)
- pthread_cancel(c->tid[i]);
- for (i = 0; i < CIPHER_THREADS; i++)
- pthread_join(c->tid[i], NULL);
+ stop_and_join_pregen_threads(c);
memset(c, 0, sizeof(*c));
free(c);

@ -30,6 +30,16 @@
#--- END OF EXAMPLES ---
# Alon Bar-Lev <alonbl@gentoo.org (09 Sep 2016)
# No upstream, no maintainer (bug #592164)
# Package will be removed from Gentoo in 30 days.
app-crypt/scl011-bin
# Alon Bar-Lev <alonbl@gentoo.org (09 Sep 2016)
# Weak cryptography (bug #592114)
# Package will be removed from Gentoo in 30 days.
app-crypt/bcrypt
# Lars Wendler <polynomial-c@gentoo.org> (06 Sep 2016)
# Breaks samba's nmbd process (bug #592502)
=sys-libs/tevent-0.9.30

@ -54,6 +54,7 @@ src_unpack() {
multilib_src_install() {
exeinto /usr/$(get_libdir)/chromium-browser/PepperFlash
doexe libpepflashplayer.so
insinto /usr/$(get_libdir)/chromium-browser/PepperFlash
doins manifest.json
if multilib_is_native_abi; then
Loading…
Cancel
Save